# Add an indicator

In this tutorial, the example indicator is given the code R999. Its methodology is "A competition completed with few submitted bids," with the default for "few" being 1 bid.

You can use the check marks to track your progress (do not reload the page).

:::{toctree}
:maxdepth: 1

setup
code
test
docs
:::
